/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is FirefoxView Mozilla Extension.
 * The Initial Developer of the Original Code is Alex Sirota <alex@elbrus.com>. 
 * Portions created by Alex Sirota are Copyright (C) 2004 Alex Sirota. All Rights Reserved.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/* 
 * This file was created because:
 *		1. Mozilla doesn't provide Windows Registry services (like delete key etc)
 *		2. Calling a simple VBScript from an extension causes Norton AntiVirus
 *			to complain about a "malicious script"
 *
 */

#include "stdafx.h"
#include <stdlib.h>

#define MENU_EXT_KEY_BASE "Software\\Microsoft\\Internet Explorer\\MenuExt"

bool CreateMenuItem(const char* name, const char* url, long context)
{
	LONG result;
	HKEY newKey;

	char aKeyName[MAX_PATH];
	lstrcpy(aKeyName, MENU_EXT_KEY_BASE);
	lstrcat(aKeyName, "\\");
	lstrcat(aKeyName, name);
		
    result = ::RegCreateKey(HKEY_CURRENT_USER, aKeyName, &newKey);
	if (result != ERROR_SUCCESS)
	{
		return false;
	}

	result = ::RegSetValue(newKey, 
							NULL,
							REG_SZ,
							url,
							lstrlen(url));					
	if (result != ERROR_SUCCESS)
	{
		RegCloseKey(newKey);
		return false;
	}

	result = ::RegSetValueEx(newKey, 
							"Contexts",
							0,
							REG_DWORD,
							(CONST BYTE *)&context,
							sizeof(context));
	if (result != ERROR_SUCCESS)
	{
		RegCloseKey(newKey);
		return false;
	}

	RegCloseKey(newKey);
	return true;
}


bool DeleteMenuItem(const char* name)
{
	LONG result;
	HKEY key;

	char aKeyName[MAX_PATH];
	lstrcpy(aKeyName, MENU_EXT_KEY_BASE);

	result = ::RegOpenKeyEx(HKEY_CURRENT_USER,
						aKeyName,
						0,
						KEY_ALL_ACCESS,
						&key);

	if (result != ERROR_SUCCESS)
	{
		return false;
	}
				
	result = ::RegDeleteKey(key, name);
	if (result != ERROR_SUCCESS)
	{
		RegCloseKey(key);
		return false;
	}
  
	RegCloseKey(key);
	return true;
}

    
int APIENTRY WinMain(HINSTANCE hInstance,
                     HINSTANCE hPrevInstance,
                     LPSTR     lpCmdLine,
                     int       nCmdShow)
{

	if (__argc < 2)
	{
		return 1;	// not enough parameters
	}

	// create menu item
	if (lstrcmp(__argv[1], "-c") == 0)
	{
		if (__argc < 5)
		{
			return 1; // not enough parameters
		}
		CreateMenuItem(__argv[2], __argv[3], atol(__argv[4]));
		return 0;
	}

	if (lstrcmp(__argv[1], "-d") == 0)
	{
		if (__argc < 3)
		{
			return 1; //not enough parameters
		}
		DeleteMenuItem(__argv[2]);
		return 0;
	}

	return 1; // wrong command line options
}
